@@ -18,9 +18,17 @@
 #' leaflet(dat) %>% addTiles() %>% addCircleMarkers(~lon, ~lat, popup=~display)
 #' }
 #' 
+#' dat[1,1] <- "Very long string I'd rather have truncated"
+#' popleaf(dat, 1:3)
+#' popleaf(dat, 1:3, truncate=16)
+#' popleaf(dat, 1:3, truncate=16, tstring="--")
+#' 
 #' @param df Data.frame
 #' @param sel Columns to be selected (Names or index or TRUE/FALSE vector).
 #'            DEFAULT: colnames(df)
+#' @param truncate Numeric: number of characters beyond which to truncate columns.
+#'                 DEFAULT: NULL (no truncation)
+#' @param tstring Charstring to add at the end if truncated. DEFAULT: "[...]"
 #' @param exclude_geometry Remove column with the name "geometry" 
 #'           (as in sf objects) from the display? DEFAULT: TRUE
 #' @param na.rm Exclude NA entries from the display? DEFAULT: FALSE
@@ -28,6 +36,8 @@
 popleaf <- function(
 df,
 sel=colnames(df),
+truncate=NULL,
+tstring="[...]",
 exclude_geometry=TRUE,
 na.rm=FALSE
 )
@@ -35,10 +45,13 @@ na.rm=FALSE
 df <- as.data.frame(df) # otherwise the next line doesn't work for sf
 sel <- colnames(df[,sel, drop=FALSE])
 if(exclude_geometry) sel <- sel[sel!="geometry"]
+truncString <- function(x, n) ifelse(nchar(x)>n, paste0(substring(x, 1, n), tstring), x)
 apply(df, MARGIN=1, function(x)
  {
  nna <- if(na.rm) !is.na(x[sel]) else TRUE
  sel <- sel[nna]
- paste(sel, ": ", x[sel], collapse="<br>")
+ value <-  x[sel]
+ if(!is.null(truncate)) value <- truncString(value, truncate)
+ paste(sel, ": ", value, collapse="<br>")
  })
 }
